
import 'package:cheminova/controller/get_delivered_controller.dart';
import 'package:cheminova/controller/get_delivered_service.dart';
import 'package:cheminova/controller/rd_get_order_controller.dart';
import 'package:cheminova/models/get_delivered_model.dart';
import 'package:cheminova/models/rd_get_order_model.dart';
import 'package:cheminova/screens/rd%20orders/rd_cancelled_details_screen.dart';
import 'package:cheminova/screens/rd%20orders/rd_delivered_details_screen.dart';
import 'package:cheminova/screens/rd%20orders/rd_dispatched_details_screen.dart';
import 'package:cheminova/screens/rd%20orders/rd_order_details_screen.dart';
import 'package:cheminova/screens/rd%20orders/rd_pending_deatils.dart';
import 'package:cheminova/screens/rd%20orders/rd_processing_details.dart';
import 'package:cheminova/widgets/input_field.dart';
import 'package:cheminova/widgets/my_drawer.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:get/get.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:intl/intl.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../../controller/get_single_invoice_Service.dart';
import '../order_management/order_management_detail_screen.dart';

class RdDeliveredScreen extends StatefulWidget {
  final GetDeliveredModel? getrdProduct;

  RdDeliveredScreen({super.key, this.getrdProduct});

  @override
  State<RdDeliveredScreen> createState() => _RdDeliveredScreenState();
}

class _RdDeliveredScreenState extends State<RdDeliveredScreen> {
  final _searchController = TextEditingController();
  final List<String> _filterList = [ "new",
    "pending",
    "processing",
    "dispatched",
    "cancelled",
    "delivered",];
  int _selectedIndex = 0;
  final GetDeliveredController _getRdProductController = Get.put(GetDeliveredController());
  final GlobalKey<RefreshIndicatorState> _refreshIndicatorKey = GlobalKey<RefreshIndicatorState>();

  @override
  void initState() {
    super.initState();
    getOrder1();
  }

  Future<void> _onRefresh() async {
    await getOrder1();
    await Future.delayed(Duration(seconds: 1));
  }

  Future<void> getOrder1() async {
    await _getRdProductController.getRDDeliveredInvoiceProduct();
    if (_getRdProductController.productProcessingRDList.isEmpty) {
      print("No orders found.");
    } else {
      print("Orders fetched successfully");
    }
  }

  String capitalizeFirstLetter(String text) {
    if (text.isEmpty) return text;
    return text[0].toUpperCase() + text.substring(1).toLowerCase();
  }

  String formatDate(String apiDate) {
    // Parse the API date string into a DateTime object
    DateTime parsedDate = DateTime.parse(apiDate).toLocal(); // Convert to local time

    // Format the date and time according to your specified format
    String formattedDate = DateFormat('EEE MMM dd yyyy hh:mm a').format(parsedDate);


    return formattedDate; // Return the formatted date string
  }



  void onOrderTap(int index) async {
    try {
      // Fetch orders and ensure you wait for it to complete
      await _getRdProductController.getRDDeliveredInvoiceProduct();

      // Log the count of fetched orders
      print('Fetched orders count: ${_getRdProductController.productProcessingRDList.length}');

      // Check if the productRDList is populated
      if (_getRdProductController.productProcessingRDList.isNotEmpty) {
        // Ensure the index is valid
        if (index >= 0 && index < _getRdProductController.productProcessingRDList.length) {
          // Get the order ID from the list based on the index
          final orderId = _getRdProductController.productProcessingRDList[index].id;
          final orderId1 = _getRdProductController.productProcessingRDList[index].id;
          // Retrieve the token from SharedPreferences
          SharedPreferences prefs = await SharedPreferences.getInstance();
          String? token = prefs.getString('token');

          // Check if the token is not null
          if (token != null) {
            // Fetch the single order using the order ID, and avoid caching issues
            final singleOrder = await GetSingleInvoiceService().fetchInvoice(token, orderId);
            final invoiceOrder = await GetDeliveredService().getRDDeliveredProduct(token);
            // Check if the single order was fetched successfully
            if (singleOrder != null) {
              // Navigate to the details screen with the fetched order
              Get.to(() => RdDeliveredDetailsScreen(
                placedOrderList: invoiceOrder![index],
                placedInvoiceList: singleOrder,
              ));
            } else {
              // Handle the case where the single order could not be fetched
              Get.snackbar("Error", "Unable to fetch order details.");
            }
          } else {
            // Handle the case where the token is null
            Get.snackbar("Error", "User not authenticated.");
          }
        } else {
          // Handle the case when the index is out of bounds
          Get.snackbar("Error", "Invalid order selection.");
        }
      } else {
        // Handle the case when the list is empty
        Get.snackbar("Error", "No orders available to display.");
      }
    } catch (e) {
      // Log any errors that occur during the process
      print('Error in onOrderTap: $e');
      Get.snackbar("Error", "An unexpected error occurred.");
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      extendBodyBehindAppBar: true,
      appBar: AppBar(
        centerTitle: true,
        backgroundColor: Colors.transparent,
        elevation: 0,
        leading: Builder(
          builder: (context) {
            return GestureDetector(
              onTap: () => Scaffold.of(context).openDrawer(),
              child: Padding(
                padding: const EdgeInsets.all(16.0),
                child: SvgPicture.asset('assets/svg/menu.svg'),
              ),
            );
          },
        ),
        actions: [
          GestureDetector(
            onTap: () => Get.back(),
            child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: SvgPicture.asset('assets/svg/back_arrow.svg'),
            ),
          ),
        ],
        title: const Text("RD Delivered Order"),
      ),
      drawer: MyDrawer(),
      body: Stack(
        fit: StackFit.expand,
        children: [
          Image.asset('assets/images/image_1.png', fit: BoxFit.cover),
          SafeArea(
            child: SingleChildScrollView(
              child: Padding(
                padding: EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
                child: RefreshIndicator(
                  key: _refreshIndicatorKey,
                  onRefresh: _onRefresh,
                  color: Colors.black,
                  backgroundColor: Colors.white,
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      InputField(
                        hintText: "Search Order",
                        labelText: "Search Order",
                        controller: _searchController,
                      ),
                      SizedBox(height: Get.height * 0.035),
                      Card(
                        margin: const EdgeInsets.symmetric(horizontal: 18),
                        shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(19),
                          side: const BorderSide(color: Color(0xFFFDFDFD)),
                        ),
                        color: const Color(0xFFB4D1E5).withOpacity(0.9),
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Column(
                            mainAxisSize: MainAxisSize.min,
                            children: [
                              // SizedBox(
                              //   height: Get.height * 0.05,
                              //   child: ListView.builder(
                              //     shrinkWrap: true,
                              //     scrollDirection: Axis.horizontal,
                              //     itemCount: _filterList.length,
                              //     itemBuilder: (context, index) => Padding(
                              //       padding: const EdgeInsets.symmetric(horizontal: 4),
                              //       child: GestureDetector(
                              //         onTap: () {
                              //           setState(() {
                              //             _selectedIndex = index; // Update selected index
                              //           });
                              //           // Navigate to different screens based on selected tab
                              //           switch (_filterList[index]) {
                              //             case "new":
                              //             //  Get.to(YourScreen1()); // Navigate to "new" orders screen
                              //               break;
                              //             case "pending":
                              //             // Get.to(YourScreen2()); // Navigate to "pending" orders screen
                              //               break;
                              //             case "processing":
                              //             //  Get.to(YourScreen3()); // Navigate to "processing" orders screen
                              //               break;
                              //           // Add more cases for other statuses
                              //             case "dispatched":
                              //             // Get.to(YourScreen4()); // Navigate to dispatched orders
                              //               break;
                              //             case "cancelled":
                              //             //   Get.to(YourScreen5()); // Navigate to cancelled orders
                              //               break;
                              //             case "delivered":
                              //             //Get.to(YourScreen6()); // Navigate to delivered orders
                              //               break;
                              //             default:
                              //             // Get.to(YourScreen1()); // Default screen
                              //           }
                              //         },
                              //         child: Chip(
                              //           label: Text(capitalizeFirstLetter(  _filterList[index])
                              //             ,
                              //             style: GoogleFonts.roboto(
                              //               fontSize: 14,
                              //               fontWeight: FontWeight.w500,
                              //               color: _selectedIndex == index ? Colors.white : Colors.black, // Change color when selected
                              //             ),
                              //           ),
                              //           backgroundColor: _selectedIndex == index ? Colors.blue : Colors.grey[300], // Change color when selected
                              //         ),
                              //       ),
                              //     ),
                              //   ),
                              // ),
                              SizedBox(
                                height: Get.height * 0.6,
                                child: Obx(() {
                                  // if (_getRdProductController.productRDList.isEmpty) {
                                  //   return Center(
                                  //     child: Text(
                                  //       'No Orders Found',
                                  //       style: GoogleFonts.roboto(fontSize: 14),
                                  //     ),
                                  //   );
                                  // }

                                  final Set<String> uniqueOrderIds = {};
                                  final List<GetDeliveredModel> uniqueOrders = [];

                                  for (var order in _getRdProductController.productProcessingRDList) {
                                    if (uniqueOrderIds.add(order.id)) {
                                      uniqueOrders.add(order);
                                    }
                                  }

                                  if (uniqueOrders.isEmpty) {
                                    return Center(
                                      child: Text(
                                        'No Orders Found',
                                        style: GoogleFonts.roboto(fontSize: 14),
                                      ),
                                    );
                                  }

                                  return ListView.builder(
                                    padding: EdgeInsets.zero,
                                    shrinkWrap: true,
                                    itemCount: uniqueOrders.length,
                                    itemBuilder: (context, index) {
                                      final order = uniqueOrders[index];

                                      // Combine product names into a single string
                                      final productNames = order.items
                                          .map((item) => capitalizeFirstLetter(item.name))
                                          .join(', ');

                                      return Padding(
                                        padding: const EdgeInsets.symmetric(vertical: 8),
                                        child: Card(
                                          child: Column(
                                            crossAxisAlignment: CrossAxisAlignment.start,
                                            children: [
                                              Padding(
                                                padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                                child: Row(
                                                  mainAxisAlignment: MainAxisAlignment.start,
                                                  children: [
                                                    Text("Order ID: ", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.bold)),
                                                    Text("${order.orderId.uniqueId}")
                                                  ],
                                                ),
                                              ),
                                              Padding(
                                                padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                                child: Row(
                                                  crossAxisAlignment: CrossAxisAlignment.start,
                                                  children: [
                                                    Text(
                                                      "Invoice ID: ",
                                                      style: GoogleFonts.roboto(
                                                        fontSize: 14,
                                                        fontWeight: FontWeight.bold,
                                                      ),
                                                    ),
                                                    Text(order.invoiceId),

                                                  ],
                                                ),
                                              ),

                                              Padding(
                                                padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                                child: Row(
                                                  crossAxisAlignment: CrossAxisAlignment.start,
                                                  children: [
                                                    Text(
                                                      "Delivered Date: ",
                                                      style: GoogleFonts.roboto(
                                                        fontSize: 14,
                                                        fontWeight: FontWeight.bold,
                                                      ),
                                                    ),
                                                    Text(
                                                      _getRdProductController.productProcessingRDList[0]!.courierStatusTimeline !=null
                                                          ? formatDate(  _getRdProductController.productProcessingRDList[0].courierStatusTimeline.delivered)
                                                          : 'N/A', // If the map is empty or null, display 'N/A'
                                                      style: GoogleFonts.roboto(
                                                        fontSize: 14,
                                                      ),
                                                    ),

                                                  ],
                                                ),
                                              ),
                                              Padding(
                                                padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                                child: Row(
                                                  mainAxisAlignment: MainAxisAlignment.start,
                                                  children: [
                                                    Text("Items: ", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.bold)),
                                                    Text("${order.items.length}"),
                                                  ],
                                                ),
                                              ),
                                              Padding(
                                                padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                                child: Row(
                                                  mainAxisAlignment: MainAxisAlignment.start,
                                                  children: [
                                                    Text("Invoice Value: ", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.bold)),
                                                    Text("${order.invoiceAmount}"),
                                                  ],
                                                ),
                                              ),
                                              Padding(
                                                padding: const EdgeInsets.fromLTRB(16, 8, 8, 8),
                                                child: Row(
                                                  mainAxisAlignment: MainAxisAlignment.start,
                                                  children: [
                                                    Text("Status: ", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.bold)),
                                                    Text(capitalizeFirstLetter("${order.courierStatus}"))

                                                  ],
                                                ),
                                              ),
                                              SizedBox(
                                                width: Get.width * 0.4,
                                                child: Padding(
                                                  padding: const EdgeInsets.all(8.0),
                                                  child: ElevatedButton(
                                                    onPressed: (){
                                                      onOrderTap(index);
                                                    },
                                                    //=>
                                                        // Get.to(() =>
                                                        //     RdDeliveredDetailsScreen(
                                                        //         placedOrderList: uniqueOrders[index])), // Navigate to detail screen
                                                    style: ElevatedButton.styleFrom(
                                                      foregroundColor: Colors.white,
                                                      backgroundColor: const Color(0xFF004791),
                                                      shape: RoundedRectangleBorder(
                                                          borderRadius: BorderRadius.circular(10)),
                                                    ),
                                                    child: Text("View Details", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.w400)),
                                                  ),
                                                ),
                                              )
                                            ],
                                          ),
                                        ),
                                      );
                                    },
                                  );
                                }),
                              )
                            ],
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}

