
import 'package:cheminova/controller/get_single_invoice_controller.dart';
import 'package:cheminova/controller/rd_get_order_controller.dart';
import 'package:cheminova/controller/rd_processing_invoice_controller.dart';
import 'package:cheminova/models/rd_get_order_model.dart';
import 'package:cheminova/models/rd_processing_invoice_model.dart';
import 'package:cheminova/screens/rd%20orders/rd_cancelled_screen.dart';
import 'package:cheminova/screens/rd%20orders/rd_delivered_screen.dart';
import 'package:cheminova/screens/rd%20orders/rd_dispatched_scree.dart';
import 'package:cheminova/screens/rd%20orders/rd_order_details_screen.dart';
import 'package:cheminova/screens/rd%20orders/rd_order_screen.dart';
import 'package:cheminova/screens/rd%20orders/rd_pending_screen.dart';
import 'package:cheminova/screens/rd%20orders/rd_processing_details.dart';
import 'package:cheminova/screens/rd%20orders/rd_processing_screen.dart';
import 'package:cheminova/widgets/input_field.dart';
import 'package:cheminova/widgets/my_drawer.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:get/get.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:intl/intl.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../../controller/get_single_invoice_Service.dart';
import '../order_management/order_management_detail_screen.dart';

class RdOrderProcessingScreen extends StatefulWidget {
  final InvoiceResponseModel? getrdProduct;

  RdOrderProcessingScreen({super.key, this.getrdProduct});

  @override
  State<RdOrderProcessingScreen> createState() => _RdOrderProcessingScreenState();
}

class _RdOrderProcessingScreenState extends State<RdOrderProcessingScreen> {
  final _searchController = TextEditingController();
  final List<String> _filterList = [ "new",
    "pending",
    "processing",
    "dispatched",
    "cancelled",
    "delivered",];
  int _selectedIndex = 0;
  final GetRDProcessingInvoiceController _getRdProductController = Get.put(GetRDProcessingInvoiceController());
  final GetSingleInvoiceController _getSingleInvoiceController = Get.put(GetSingleInvoiceController());
  final GlobalKey<RefreshIndicatorState> _refreshIndicatorKey = GlobalKey<RefreshIndicatorState>();

  @override
  void initState() {
    super.initState();
    getOrder1();

  }

  Future<void> _onRefresh() async {
    await getOrder1();
    //await Future.delayed(Duration(seconds: 1));
  }

  Future<void> getOrder1() async {
    await _getRdProductController.getRDProcessingInvoiceProduct();
    if (_getRdProductController.productProcessingRDList.isEmpty) {
      print("No orders found.");
    } else {
      print("Orders fetched successfully");
    }
    setState(() {

    });
  }





  String capitalizeFirstLetter(String text) {
    if (text.isEmpty) return text;
    return text[0].toUpperCase() + text.substring(1).toLowerCase();
  }

  String formatDate(String apiDate) {
    // Parse the API date string into a DateTime object
    DateTime parsedDate = DateTime.parse(apiDate).toLocal(); // Convert to local time

    // Format the date and time according to your specified format
    String formattedDate = DateFormat('EEE MMM dd yyyy hh:mm a').format(parsedDate);


    return formattedDate; // Return the formatted date string
  }


  void onOrderTap(int index) async {
    try {
      // Fetch orders and ensure you wait for it to complete
      await _getRdProductController.getRDProcessingInvoiceProduct();

      // Log the count of fetched orders
      print('Fetched orders count: ${_getRdProductController.productProcessingRDList.length}');

      if (_getRdProductController.productProcessingRDList.isNotEmpty) {
        // Ensure the index is valid
        if (index >= 0 && index < _getRdProductController.productProcessingRDList.length) {
          // Get the order ID from the list based on the index
          final orderId = _getRdProductController.productProcessingRDList[index].id;

          // Retrieve the token from SharedPreferences
          SharedPreferences prefs = await SharedPreferences.getInstance();
          String? token = prefs.getString('token');

          // Check if the token is not null
          if (token != null) {
            // Fetch the single order using the order ID, and avoid caching issues
            final singleOrder = await GetSingleInvoiceService().fetchInvoice(token, orderId);

            // Check if the single order was fetched successfully
            if (singleOrder != null) {
              // Navigate to the details screen with the fetched order
              Get.to(() => RdOrderProcessingDetailScreen(
                placeInvoiceList: singleOrder,
              // orderId: orderId,
              ));
            }   } else {
            // Handle the case where the single order could not be fetched
            Get.snackbar("Error", "Unable to fetch order details.");
          }
        } else {
          // Handle the case where the token is null
          Get.snackbar("Error", "User not authenticated.");
        }
      } else {
        // Handle the case when the index is out of bounds
        Get.snackbar("Error", "Invalid order selection.");
      }

  } catch (e) {
  // Log any errors that occur during the process
  print('Error in onOrderTap: $e');
  Get.snackbar("Error", "An unexpected error occurred.");
  }
}



@override
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      extendBodyBehindAppBar: true,
      appBar: AppBar(
        centerTitle: true,
        backgroundColor: Colors.transparent,
        elevation: 0,
        leading: Builder(
          builder: (context) {
            return GestureDetector(
              onTap: () => Scaffold.of(context).openDrawer(),
              child: Padding(
                padding: const EdgeInsets.all(16.0),
                child: SvgPicture.asset('assets/svg/menu.svg'),
              ),
            );
          },
        ),
        actions: [
          GestureDetector(
            onTap: () => Get.back(),
            child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: SvgPicture.asset('assets/svg/back_arrow.svg'),
            ),
          ),
        ],
        title: const Text("RD Processing Order"),
      ),
      drawer: MyDrawer(),
      body: Stack(
          fit: StackFit.expand,
          children: [
          Image.asset('assets/images/image_1.png', fit: BoxFit.cover),
      SafeArea(
        child: SingleChildScrollView(
          child: Padding(
            padding: EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
            child: RefreshIndicator(
              key: _refreshIndicatorKey,
              onRefresh: _onRefresh,
              color: Colors.black,
              backgroundColor: Colors.white,
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: [
                  InputField(
                    hintText: "Search Order",
                    labelText: "Search Order",
                    controller: _searchController,
                  ),
                  SizedBox(height: Get.height * 0.035),
                  Card(
                    margin: const EdgeInsets.symmetric(horizontal: 18),
                    shape: RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(19),
                      side: const BorderSide(color: Color(0xFFFDFDFD)),
                    ),
                    color: const Color(0xFFB4D1E5).withOpacity(0.9),
                    child: Padding(
                      padding: const EdgeInsets.all(12.0),
                      child: Column(
                        mainAxisSize: MainAxisSize.min,
                        children: [

                          SizedBox(
                            height: Get.height * 0.6,
                            child:


                            ListView.builder(
                                padding: EdgeInsets.zero,
                                shrinkWrap: true,
                                itemCount:_getRdProductController.productProcessingRDList.length,
                                itemBuilder: (context, index) {
                                  final order = _getRdProductController.productProcessingRDList[index];

                                  // Combine product names into a single string
                                  final productNames = order.items
                                      .map((item) => capitalizeFirstLetter(item.name))
                                      .join(', ');

                                  return Padding(
                                    padding: const EdgeInsets.symmetric(vertical: 8),
                                    child: Card(
                                      child: Column(
                                        crossAxisAlignment: CrossAxisAlignment.start,
                                        children: [
                                          Padding(
                                            padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                            child: Row(
                                              mainAxisAlignment: MainAxisAlignment.start,
                                              children: [
                                                Text("Order ID: ", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.bold)),
                                                Text("${order.orderId.uniqueId}")
                                              ],
                                            ),
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                            child: Row(
                                              crossAxisAlignment: CrossAxisAlignment.start,
                                              children: [
                                                Text(
                                                  "Invoice ID: ",
                                                  style: GoogleFonts.roboto(
                                                    fontSize: 14,
                                                    fontWeight: FontWeight.bold,
                                                  ),
                                                ),
                                                Text(order.invoiceId),

                                              ],
                                            ),
                                          ),

                                          Padding(
                                            padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                            child: Row(
                                              crossAxisAlignment: CrossAxisAlignment.start,
                                              children: [
                                                Text(
                                                  "Processing Date: ",
                                                  style: GoogleFonts.roboto(
                                                    fontSize: 14,
                                                    fontWeight: FontWeight.bold,
                                                  ),
                                                ),
                                             // Text(formatDate(widget.getrdProduct!.courierStatusTimeline.processing)),
                                              Text(
                                                _getRdProductController.productProcessingRDList[0].courierStatusTimeline.isNotEmpty == true
                                                    ? formatDate( _getRdProductController.productProcessingRDList[0].courierStatusTimeline["processing"].toString())
                                                    : 'N/A', // If the map is empty or null, display 'N/A'
                                                style: GoogleFonts.roboto(
                                                  fontSize: 14,
                                                ),
                                              ),
                                              ],
                                            ),
                                          ),

                                          Padding(
                                            padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                            child: Row(
                                              mainAxisAlignment: MainAxisAlignment.start,
                                              children: [
                                                Text("Items: ", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.bold)),
                                                Text("${order.items.length}"),
                                              ],
                                            ),
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.fromLTRB(16, 8, 8, 0),
                                            child: Row(
                                              mainAxisAlignment: MainAxisAlignment.start,
                                              children: [
                                                Text("Invoice Value: ", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.bold)),
                                                Text("${order.invoiceAmount}"),
                                              ],
                                            ),
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.fromLTRB(16, 8, 8, 8),
                                            child: Row(
                                              mainAxisAlignment: MainAxisAlignment.start,
                                              children: [
                                                Text("Status: ", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.bold)),
                                                Text(capitalizeFirstLetter("${order.courierStatus}"))
                                              ],
                                            ),
                                          ),
                                          SizedBox(
                                            width: Get.width * 0.4,
                                            child: Padding(
                                              padding: const EdgeInsets.all(8.0),
                                              child: ElevatedButton(
                                                onPressed: () async{
                                                  //await _getSingleInvoiceController.fetchInvoice(widget.getrdProduct!.id);
                                                     onOrderTap(index);
                                                  // Now navigate to the details screen
                                                  //Get.to(() => RdOrderProcessingDetailScreen());
                                                },
                                                //=>
                                                  //  Get.to(() => RdOrderProcessingDetailScreen(placedOrderList:_getRdProductController.productProcessingRDList[index])),
                                                style: ElevatedButton.styleFrom(
                                                  foregroundColor: Colors.white,
                                                  backgroundColor: const Color(0xFF004791),
                                                  shape: RoundedRectangleBorder(
                                                    borderRadius: BorderRadius.circular(10),
                                                  ),
                                                ),
                                                child: Text("View Details", style: GoogleFonts.roboto(fontSize: 14, fontWeight: FontWeight.w400)),
                                              ),
                                            ),
                                          )
                                        ],
                                      ),
                                    ),
                                  );
                                },
                              )
                          ),

                        ],
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      )]
      ),
    );
  }
}



